@@ -57,6 +57,7 @@
 #include <QList>
 #include <qpropertyanimation.h>
 #include <qnamespace.h>
+#include <qsharedmemory.h>
 #include <qmimedatabase.h>
 #include <qidentityproxymodel.h>
 #include <qfilesystemwatcher.h>
@@ -234,7 +235,7 @@ enum : int {
     SBK_QCOMMANDLINEPARSER_OPTIONSAFTERPOSITIONALARGUMENTSMODE_IDX = 49,
     SBK_QCOMMANDLINEPARSER_IDX                               = 48,
     SBK_QCONCATENATETABLESPROXYMODEL_IDX                     = 51,
-    SBK_QCOREAPPLICATION_APPLICATIONFLAGS_IDX                = 413,
+    SBK_QCOREAPPLICATION_APPLICATIONFLAGS_IDX                = 416,
     SBK_QCOREAPPLICATION_IDX                                 = 52,
     SBK_QCRYPTOGRAPHICHASH_ALGORITHM_IDX                     = 54,
     SBK_QCRYPTOGRAPHICHASH_IDX                               = 53,
@@ -311,17 +312,17 @@ enum : int {
     SBK_QLINEF_INTERSECTIONTYPE_IDX                          = 167,
     SBK_QLINEF_IDX                                           = 166,
     SBK_QLOCALE_LANGUAGE_IDX                                 = 173,
-    SBK_QLOCALE_SCRIPT_IDX                                   = 416,
+    SBK_QLOCALE_SCRIPT_IDX                                   = 419,
     SBK_QLOCALE_COUNTRY_IDX                                  = 169,
     SBK_QLOCALE_MEASUREMENTSYSTEM_IDX                        = 174,
     SBK_QLOCALE_FORMATTYPE_IDX                               = 172,
     SBK_QLOCALE_NUMBEROPTION_IDX                             = 175,
     SBK_QFLAGS_QLOCALE_NUMBEROPTION_IDX                      = 106,
     SBK_QLOCALE_FLOATINGPOINTPRECISIONOPTION_IDX             = 171,
-    SBK_QLOCALE_CURRENCYSYMBOLFORMAT_IDX                     = 414,
+    SBK_QLOCALE_CURRENCYSYMBOLFORMAT_IDX                     = 417,
     SBK_QLOCALE_DATASIZEFORMAT_IDX                           = 170,
     SBK_QFLAGS_QLOCALE_DATASIZEFORMAT_IDX                    = 105,
-    SBK_QLOCALE_QUOTATIONSTYLE_IDX                           = 415,
+    SBK_QLOCALE_QUOTATIONSTYLE_IDX                           = 418,
     SBK_QLOCALE_IDX                                          = 168,
     SBK_QLOCKFILE_LOCKERROR_IDX                              = 177,
     SBK_QLOCKFILE_IDX                                        = 176,
@@ -396,206 +397,209 @@ enum : int {
     SBK_QSETTINGS_FORMAT_IDX                                 = 242,
     SBK_QSETTINGS_SCOPE_IDX                                  = 243,
     SBK_QSETTINGS_IDX                                        = 241,
-    SBK_QSIGNALBLOCKER_IDX                                   = 245,
-    SBK_QSIGNALMAPPER_IDX                                    = 246,
-    SBK_QSIZE_IDX                                            = 247,
-    SBK_QSIZEF_IDX                                           = 248,
-    SBK_QSOCKETDESCRIPTOR_IDX                                = 249,
-    SBK_QSOCKETNOTIFIER_TYPE_IDX                             = 251,
-    SBK_QSOCKETNOTIFIER_IDX                                  = 250,
-    SBK_QSORTFILTERPROXYMODEL_IDX                            = 252,
-    SBK_QSTANDARDPATHS_STANDARDLOCATION_IDX                  = 255,
-    SBK_QSTANDARDPATHS_LOCATEOPTION_IDX                      = 254,
+    SBK_QSHAREDMEMORY_ACCESSMODE_IDX                         = 246,
+    SBK_QSHAREDMEMORY_SHAREDMEMORYERROR_IDX                  = 247,
+    SBK_QSHAREDMEMORY_IDX                                    = 245,
+    SBK_QSIGNALBLOCKER_IDX                                   = 248,
+    SBK_QSIGNALMAPPER_IDX                                    = 249,
+    SBK_QSIZE_IDX                                            = 250,
+    SBK_QSIZEF_IDX                                           = 251,
+    SBK_QSOCKETDESCRIPTOR_IDX                                = 252,
+    SBK_QSOCKETNOTIFIER_TYPE_IDX                             = 254,
+    SBK_QSOCKETNOTIFIER_IDX                                  = 253,
+    SBK_QSORTFILTERPROXYMODEL_IDX                            = 255,
+    SBK_QSTANDARDPATHS_STANDARDLOCATION_IDX                  = 258,
+    SBK_QSTANDARDPATHS_LOCATEOPTION_IDX                      = 257,
     SBK_QFLAGS_QSTANDARDPATHS_LOCATEOPTION_IDX               = 111,
-    SBK_QSTANDARDPATHS_IDX                                   = 253,
-    SBK_QSTORAGEINFO_IDX                                     = 256,
-    SBK_QSTRINGCONVERTER_ENCODING_IDX                        = 258,
-    SBK_QSTRINGCONVERTER_IDX                                 = 257,
-    SBK_QSTRINGCONVERTERBASE_FLAG_IDX                        = 260,
+    SBK_QSTANDARDPATHS_IDX                                   = 256,
+    SBK_QSTORAGEINFO_IDX                                     = 259,
+    SBK_QSTRINGCONVERTER_ENCODING_IDX                        = 261,
+    SBK_QSTRINGCONVERTER_IDX                                 = 260,
+    SBK_QSTRINGCONVERTERBASE_FLAG_IDX                        = 263,
     SBK_QFLAGS_QSTRINGCONVERTERBASE_FLAG_IDX                 = 112,
-    SBK_QSTRINGCONVERTERBASE_IDX                             = 259,
-    SBK_QSTRINGCONVERTERBASE_STATE_IDX                       = 261,
-    SBK_QSTRINGDECODER_IDX                                   = 262,
-    SBK_QSTRINGENCODER_IDX                                   = 263,
-    SBK_QSTRINGLISTMODEL_IDX                                 = 264,
-    SBK_QSYSINFO_SIZES_IDX                                   = 267,
-    SBK_QSYSINFO_ENDIAN_IDX                                  = 266,
-    SBK_QSYSINFO_IDX                                         = 265,
-    SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX                      = 269,
-    SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX            = 270,
-    SBK_QSYSTEMSEMAPHORE_IDX                                 = 268,
-    SBK_QTEMPORARYDIR_IDX                                    = 271,
-    SBK_QTEMPORARYFILE_IDX                                   = 272,
-    SBK_QTEXTBOUNDARYFINDER_BOUNDARYTYPE_IDX                 = 275,
-    SBK_QTEXTBOUNDARYFINDER_BOUNDARYREASON_IDX               = 274,
+    SBK_QSTRINGCONVERTERBASE_IDX                             = 262,
+    SBK_QSTRINGCONVERTERBASE_STATE_IDX                       = 264,
+    SBK_QSTRINGDECODER_IDX                                   = 265,
+    SBK_QSTRINGENCODER_IDX                                   = 266,
+    SBK_QSTRINGLISTMODEL_IDX                                 = 267,
+    SBK_QSYSINFO_SIZES_IDX                                   = 270,
+    SBK_QSYSINFO_ENDIAN_IDX                                  = 269,
+    SBK_QSYSINFO_IDX                                         = 268,
+    SBK_QSYSTEMSEMAPHORE_ACCESSMODE_IDX                      = 272,
+    SBK_QSYSTEMSEMAPHORE_SYSTEMSEMAPHOREERROR_IDX            = 273,
+    SBK_QSYSTEMSEMAPHORE_IDX                                 = 271,
+    SBK_QTEMPORARYDIR_IDX                                    = 274,
+    SBK_QTEMPORARYFILE_IDX                                   = 275,
+    SBK_QTEXTBOUNDARYFINDER_BOUNDARYTYPE_IDX                 = 278,
+    SBK_QTEXTBOUNDARYFINDER_BOUNDARYREASON_IDX               = 277,
     SBK_QFLAGS_QTEXTBOUNDARYFINDER_BOUNDARYREASON_IDX        = 113,
-    SBK_QTEXTBOUNDARYFINDER_IDX                              = 273,
-    SBK_QTEXTSTREAM_REALNUMBERNOTATION_IDX                   = 279,
-    SBK_QTEXTSTREAM_FIELDALIGNMENT_IDX                       = 277,
-    SBK_QTEXTSTREAM_STATUS_IDX                               = 280,
-    SBK_QTEXTSTREAM_NUMBERFLAG_IDX                           = 278,
+    SBK_QTEXTBOUNDARYFINDER_IDX                              = 276,
+    SBK_QTEXTSTREAM_REALNUMBERNOTATION_IDX                   = 282,
+    SBK_QTEXTSTREAM_FIELDALIGNMENT_IDX                       = 280,
+    SBK_QTEXTSTREAM_STATUS_IDX                               = 283,
+    SBK_QTEXTSTREAM_NUMBERFLAG_IDX                           = 281,
     SBK_QFLAGS_QTEXTSTREAM_NUMBERFLAG_IDX                    = 114,
-    SBK_QTEXTSTREAM_IDX                                      = 276,
-    SBK_QTEXTSTREAMMANIPULATOR_IDX                           = 281,
-    SBK_QTHREAD_PRIORITY_IDX                                 = 283,
-    SBK_QTHREAD_IDX                                          = 282,
-    SBK_QTHREADPOOL_IDX                                      = 284,
-    SBK_QTIME_IDX                                            = 285,
-    SBK_QTIMELINE_STATE_IDX                                  = 288,
-    SBK_QTIMELINE_DIRECTION_IDX                              = 287,
-    SBK_QTIMELINE_IDX                                        = 286,
-    SBK_QTIMEZONE_TIMETYPE_IDX                               = 292,
-    SBK_QTIMEZONE_NAMETYPE_IDX                               = 290,
-    SBK_QTIMEZONE_IDX                                        = 289,
-    SBK_QTIMEZONE_OFFSETDATA_IDX                             = 291,
-    SBK_QTIMER_IDX                                           = 293,
-    SBK_QTIMEREVENT_IDX                                      = 294,
-    SBK_QTRANSLATOR_IDX                                      = 295,
-    SBK_QTRANSPOSEPROXYMODEL_IDX                             = 296,
-    SBK_QURL_PARSINGMODE_IDX                                 = 299,
-    SBK_QURL_URLFORMATTINGOPTION_IDX                         = 300,
-    SBK_QURL_COMPONENTFORMATTINGOPTION_IDX                   = 298,
+    SBK_QTEXTSTREAM_IDX                                      = 279,
+    SBK_QTEXTSTREAMMANIPULATOR_IDX                           = 284,
+    SBK_QTHREAD_PRIORITY_IDX                                 = 286,
+    SBK_QTHREAD_IDX                                          = 285,
+    SBK_QTHREADPOOL_IDX                                      = 287,
+    SBK_QTIME_IDX                                            = 288,
+    SBK_QTIMELINE_STATE_IDX                                  = 291,
+    SBK_QTIMELINE_DIRECTION_IDX                              = 290,
+    SBK_QTIMELINE_IDX                                        = 289,
+    SBK_QTIMEZONE_TIMETYPE_IDX                               = 295,
+    SBK_QTIMEZONE_NAMETYPE_IDX                               = 293,
+    SBK_QTIMEZONE_IDX                                        = 292,
+    SBK_QTIMEZONE_OFFSETDATA_IDX                             = 294,
+    SBK_QTIMER_IDX                                           = 296,
+    SBK_QTIMEREVENT_IDX                                      = 297,
+    SBK_QTRANSLATOR_IDX                                      = 298,
+    SBK_QTRANSPOSEPROXYMODEL_IDX                             = 299,
+    SBK_QURL_PARSINGMODE_IDX                                 = 302,
+    SBK_QURL_URLFORMATTINGOPTION_IDX                         = 303,
+    SBK_QURL_COMPONENTFORMATTINGOPTION_IDX                   = 301,
     SBK_QFLAGS_QURL_COMPONENTFORMATTINGOPTION_IDX            = 115,
-    SBK_QURL_USERINPUTRESOLUTIONOPTION_IDX                   = 301,
+    SBK_QURL_USERINPUTRESOLUTIONOPTION_IDX                   = 304,
     SBK_QFLAGS_QURL_USERINPUTRESOLUTIONOPTION_IDX            = 117,
-    SBK_QURL_IDX                                             = 297,
-    SBK_QURLQUERY_IDX                                        = 302,
-    SBK_QUUID_VARIANT_IDX                                    = 305,
-    SBK_QUUID_VERSION_IDX                                    = 306,
-    SBK_QUUID_STRINGFORMAT_IDX                               = 304,
-    SBK_QUUID_IDX                                            = 303,
-    SBK_QVARIANTANIMATION_IDX                                = 307,
-    SBK_QVERSIONNUMBER_IDX                                   = 308,
-    SBK_QWAITCONDITION_IDX                                   = 309,
-    SBK_QWRITELOCKER_IDX                                     = 310,
-    SBK_QXMLSTREAMATTRIBUTE_IDX                              = 311,
-    SBK_QXMLSTREAMATTRIBUTES_IDX                             = 312,
-    SBK_QXMLSTREAMENTITYDECLARATION_IDX                      = 313,
-    SBK_QXMLSTREAMENTITYRESOLVER_IDX                         = 314,
-    SBK_QXMLSTREAMNAMESPACEDECLARATION_IDX                   = 315,
-    SBK_QXMLSTREAMNOTATIONDECLARATION_IDX                    = 316,
-    SBK_QXMLSTREAMREADER_TOKENTYPE_IDX                       = 320,
-    SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX        = 319,
-    SBK_QXMLSTREAMREADER_ERROR_IDX                           = 318,
-    SBK_QXMLSTREAMREADER_IDX                                 = 317,
-    SBK_QXMLSTREAMWRITER_IDX                                 = 321,
-    SBK_QT_GLOBALCOLOR_IDX                                   = 356,
-    SBK_QT_MOUSEBUTTON_IDX                                   = 372,
+    SBK_QURL_IDX                                             = 300,
+    SBK_QURLQUERY_IDX                                        = 305,
+    SBK_QUUID_VARIANT_IDX                                    = 308,
+    SBK_QUUID_VERSION_IDX                                    = 309,
+    SBK_QUUID_STRINGFORMAT_IDX                               = 307,
+    SBK_QUUID_IDX                                            = 306,
+    SBK_QVARIANTANIMATION_IDX                                = 310,
+    SBK_QVERSIONNUMBER_IDX                                   = 311,
+    SBK_QWAITCONDITION_IDX                                   = 312,
+    SBK_QWRITELOCKER_IDX                                     = 313,
+    SBK_QXMLSTREAMATTRIBUTE_IDX                              = 314,
+    SBK_QXMLSTREAMATTRIBUTES_IDX                             = 315,
+    SBK_QXMLSTREAMENTITYDECLARATION_IDX                      = 316,
+    SBK_QXMLSTREAMENTITYRESOLVER_IDX                         = 317,
+    SBK_QXMLSTREAMNAMESPACEDECLARATION_IDX                   = 318,
+    SBK_QXMLSTREAMNOTATIONDECLARATION_IDX                    = 319,
+    SBK_QXMLSTREAMREADER_TOKENTYPE_IDX                       = 323,
+    SBK_QXMLSTREAMREADER_READELEMENTTEXTBEHAVIOUR_IDX        = 322,
+    SBK_QXMLSTREAMREADER_ERROR_IDX                           = 321,
+    SBK_QXMLSTREAMREADER_IDX                                 = 320,
+    SBK_QXMLSTREAMWRITER_IDX                                 = 324,
+    SBK_QT_GLOBALCOLOR_IDX                                   = 359,
+    SBK_QT_MOUSEBUTTON_IDX                                   = 375,
     SBK_QFLAGS_QT_MOUSEBUTTON_IDX                            = 131,
-    SBK_QT_ORIENTATION_IDX                                   = 377,
+    SBK_QT_ORIENTATION_IDX                                   = 380,
     SBK_QFLAGS_QT_ORIENTATION_IDX                            = 133,
-    SBK_QT_FOCUSPOLICY_IDX                                   = 351,
-    SBK_QT_TABFOCUSBEHAVIOR_IDX                              = 390,
-    SBK_QT_SORTORDER_IDX                                     = 388,
-    SBK_QT_SPLITBEHAVIORFLAGS_IDX                            = 389,
+    SBK_QT_FOCUSPOLICY_IDX                                   = 354,
+    SBK_QT_TABFOCUSBEHAVIOR_IDX                              = 393,
+    SBK_QT_SORTORDER_IDX                                     = 391,
+    SBK_QT_SPLITBEHAVIORFLAGS_IDX                            = 392,
     SBK_QFLAGS_QT_SPLITBEHAVIORFLAGS_IDX                     = 135,
-    SBK_QT_TILERULE_IDX                                      = 395,
-    SBK_QT_ALIGNMENTFLAG_IDX                                 = 323,
+    SBK_QT_TILERULE_IDX                                      = 398,
+    SBK_QT_ALIGNMENTFLAG_IDX                                 = 326,
     SBK_QFLAGS_QT_ALIGNMENTFLAG_IDX                          = 118,
-    SBK_QT_TEXTFLAG_IDX                                      = 392,
-    SBK_QT_TEXTELIDEMODE_IDX                                 = 391,
-    SBK_QT_WHITESPACEMODE_IDX                                = 404,
-    SBK_QT_HITTESTACCURACY_IDX                               = 358,
-    SBK_QT_WINDOWTYPE_IDX                                    = 409,
+    SBK_QT_TEXTFLAG_IDX                                      = 395,
+    SBK_QT_TEXTELIDEMODE_IDX                                 = 394,
+    SBK_QT_WHITESPACEMODE_IDX                                = 407,
+    SBK_QT_HITTESTACCURACY_IDX                               = 361,
+    SBK_QT_WINDOWTYPE_IDX                                    = 412,
     SBK_QFLAGS_QT_WINDOWTYPE_IDX                             = 140,
-    SBK_QT_WINDOWSTATE_IDX                                   = 408,
+    SBK_QT_WINDOWSTATE_IDX                                   = 411,
     SBK_QFLAGS_QT_WINDOWSTATE_IDX                            = 139,
-    SBK_QT_APPLICATIONSTATE_IDX                              = 326,
+    SBK_QT_APPLICATIONSTATE_IDX                              = 329,
     SBK_QFLAGS_QT_APPLICATIONSTATE_IDX                       = 119,
-    SBK_QT_SCREENORIENTATION_IDX                             = 382,
+    SBK_QT_SCREENORIENTATION_IDX                             = 385,
     SBK_QFLAGS_QT_SCREENORIENTATION_IDX                      = 134,
-    SBK_QT_WIDGETATTRIBUTE_IDX                               = 405,
-    SBK_QT_APPLICATIONATTRIBUTE_IDX                          = 325,
-    SBK_QT_IMAGECONVERSIONFLAG_IDX                           = 359,
+    SBK_QT_WIDGETATTRIBUTE_IDX                               = 408,
+    SBK_QT_APPLICATIONATTRIBUTE_IDX                          = 328,
+    SBK_QT_IMAGECONVERSIONFLAG_IDX                           = 362,
     SBK_QFLAGS_QT_IMAGECONVERSIONFLAG_IDX                    = 125,
-    SBK_QT_BGMODE_IDX                                        = 330,
-    SBK_QT_KEY_IDX                                           = 366,
-    SBK_QT_KEYBOARDMODIFIER_IDX                              = 367,
+    SBK_QT_BGMODE_IDX                                        = 333,
+    SBK_QT_KEY_IDX                                           = 369,
+    SBK_QT_KEYBOARDMODIFIER_IDX                              = 370,
     SBK_QFLAGS_QT_KEYBOARDMODIFIER_IDX                       = 129,
-    SBK_QT_MODIFIER_IDX                                      = 371,
-    SBK_QT_ARROWTYPE_IDX                                     = 327,
-    SBK_QT_PENSTYLE_IDX                                      = 380,
-    SBK_QT_PENCAPSTYLE_IDX                                   = 378,
-    SBK_QT_PENJOINSTYLE_IDX                                  = 379,
-    SBK_QT_BRUSHSTYLE_IDX                                    = 331,
-    SBK_QT_SIZEMODE_IDX                                      = 387,
-    SBK_QT_UIEFFECT_IDX                                      = 403,
-    SBK_QT_CURSORSHAPE_IDX                                   = 340,
-    SBK_QT_TEXTFORMAT_IDX                                    = 393,
-    SBK_QT_ASPECTRATIOMODE_IDX                               = 328,
-    SBK_QT_DOCKWIDGETAREA_IDX                                = 343,
+    SBK_QT_MODIFIER_IDX                                      = 374,
+    SBK_QT_ARROWTYPE_IDX                                     = 330,
+    SBK_QT_PENSTYLE_IDX                                      = 383,
+    SBK_QT_PENCAPSTYLE_IDX                                   = 381,
+    SBK_QT_PENJOINSTYLE_IDX                                  = 382,
+    SBK_QT_BRUSHSTYLE_IDX                                    = 334,
+    SBK_QT_SIZEMODE_IDX                                      = 390,
+    SBK_QT_UIEFFECT_IDX                                      = 406,
+    SBK_QT_CURSORSHAPE_IDX                                   = 343,
+    SBK_QT_TEXTFORMAT_IDX                                    = 396,
+    SBK_QT_ASPECTRATIOMODE_IDX                               = 331,
+    SBK_QT_DOCKWIDGETAREA_IDX                                = 346,
     SBK_QFLAGS_QT_DOCKWIDGETAREA_IDX                         = 120,
-    SBK_QT_DOCKWIDGETAREASIZES_IDX                           = 344,
-    SBK_QT_TOOLBARAREA_IDX                                   = 398,
+    SBK_QT_DOCKWIDGETAREASIZES_IDX                           = 347,
+    SBK_QT_TOOLBARAREA_IDX                                   = 401,
     SBK_QFLAGS_QT_TOOLBARAREA_IDX                            = 137,
-    SBK_QT_TOOLBARAREASIZES_IDX                              = 399,
-    SBK_QT_DATEFORMAT_IDX                                    = 341,
-    SBK_QT_TIMESPEC_IDX                                      = 396,
-    SBK_QT_DAYOFWEEK_IDX                                     = 342,
-    SBK_QT_SCROLLBARPOLICY_IDX                               = 383,
-    SBK_QT_CASESENSITIVITY_IDX                               = 332,
-    SBK_QT_CORNER_IDX                                        = 339,
-    SBK_QT_EDGE_IDX                                          = 346,
+    SBK_QT_TOOLBARAREASIZES_IDX                              = 402,
+    SBK_QT_DATEFORMAT_IDX                                    = 344,
+    SBK_QT_TIMESPEC_IDX                                      = 399,
+    SBK_QT_DAYOFWEEK_IDX                                     = 345,
+    SBK_QT_SCROLLBARPOLICY_IDX                               = 386,
+    SBK_QT_CASESENSITIVITY_IDX                               = 335,
+    SBK_QT_CORNER_IDX                                        = 342,
+    SBK_QT_EDGE_IDX                                          = 349,
     SBK_QFLAGS_QT_EDGE_IDX                                   = 122,
-    SBK_QT_CONNECTIONTYPE_IDX                                = 336,
-    SBK_QT_SHORTCUTCONTEXT_IDX                               = 385,
-    SBK_QT_FILLRULE_IDX                                      = 349,
-    SBK_QT_MASKMODE_IDX                                      = 369,
-    SBK_QT_CLIPOPERATION_IDX                                 = 335,
-    SBK_QT_ITEMSELECTIONMODE_IDX                             = 364,
-    SBK_QT_ITEMSELECTIONOPERATION_IDX                        = 365,
-    SBK_QT_TRANSFORMATIONMODE_IDX                            = 402,
-    SBK_QT_AXIS_IDX                                          = 329,
-    SBK_QT_FOCUSREASON_IDX                                   = 352,
-    SBK_QT_CONTEXTMENUPOLICY_IDX                             = 337,
-    SBK_QT_INPUTMETHODQUERY_IDX                              = 361,
+    SBK_QT_CONNECTIONTYPE_IDX                                = 339,
+    SBK_QT_SHORTCUTCONTEXT_IDX                               = 388,
+    SBK_QT_FILLRULE_IDX                                      = 352,
+    SBK_QT_MASKMODE_IDX                                      = 372,
+    SBK_QT_CLIPOPERATION_IDX                                 = 338,
+    SBK_QT_ITEMSELECTIONMODE_IDX                             = 367,
+    SBK_QT_ITEMSELECTIONOPERATION_IDX                        = 368,
+    SBK_QT_TRANSFORMATIONMODE_IDX                            = 405,
+    SBK_QT_AXIS_IDX                                          = 332,
+    SBK_QT_FOCUSREASON_IDX                                   = 355,
+    SBK_QT_CONTEXTMENUPOLICY_IDX                             = 340,
+    SBK_QT_INPUTMETHODQUERY_IDX                              = 364,
     SBK_QFLAGS_QT_INPUTMETHODQUERY_IDX                       = 127,
-    SBK_QT_INPUTMETHODHINT_IDX                               = 360,
+    SBK_QT_INPUTMETHODHINT_IDX                               = 363,
     SBK_QFLAGS_QT_INPUTMETHODHINT_IDX                        = 126,
-    SBK_QT_ENTERKEYTYPE_IDX                                  = 347,
-    SBK_QT_TOOLBUTTONSTYLE_IDX                               = 400,
-    SBK_QT_LAYOUTDIRECTION_IDX                               = 368,
-    SBK_QT_ANCHORPOINT_IDX                                   = 324,
-    SBK_QT_FINDCHILDOPTION_IDX                               = 350,
+    SBK_QT_ENTERKEYTYPE_IDX                                  = 350,
+    SBK_QT_TOOLBUTTONSTYLE_IDX                               = 403,
+    SBK_QT_LAYOUTDIRECTION_IDX                               = 371,
+    SBK_QT_ANCHORPOINT_IDX                                   = 327,
+    SBK_QT_FINDCHILDOPTION_IDX                               = 353,
     SBK_QFLAGS_QT_FINDCHILDOPTION_IDX                        = 123,
-    SBK_QT_DROPACTION_IDX                                    = 345,
+    SBK_QT_DROPACTION_IDX                                    = 348,
     SBK_QFLAGS_QT_DROPACTION_IDX                             = 121,
-    SBK_QT_CHECKSTATE_IDX                                    = 333,
-    SBK_QT_ITEMDATAROLE_IDX                                  = 362,
-    SBK_QT_ITEMFLAG_IDX                                      = 363,
+    SBK_QT_CHECKSTATE_IDX                                    = 336,
+    SBK_QT_ITEMDATAROLE_IDX                                  = 365,
+    SBK_QT_ITEMFLAG_IDX                                      = 366,
     SBK_QFLAGS_QT_ITEMFLAG_IDX                               = 128,
-    SBK_QT_MATCHFLAG_IDX                                     = 370,
+    SBK_QT_MATCHFLAG_IDX                                     = 373,
     SBK_QFLAGS_QT_MATCHFLAG_IDX                              = 130,
-    SBK_QT_WINDOWMODALITY_IDX                                = 407,
-    SBK_QT_TEXTINTERACTIONFLAG_IDX                           = 394,
+    SBK_QT_WINDOWMODALITY_IDX                                = 410,
+    SBK_QT_TEXTINTERACTIONFLAG_IDX                           = 397,
     SBK_QFLAGS_QT_TEXTINTERACTIONFLAG_IDX                    = 136,
-    SBK_QT_EVENTPRIORITY_IDX                                 = 348,
-    SBK_QT_SIZEHINT_IDX                                      = 386,
-    SBK_QT_WINDOWFRAMESECTION_IDX                            = 406,
-    SBK_QT_COORDINATESYSTEM_IDX                              = 338,
-    SBK_QT_TOUCHPOINTSTATE_IDX                               = 401,
+    SBK_QT_EVENTPRIORITY_IDX                                 = 351,
+    SBK_QT_SIZEHINT_IDX                                      = 389,
+    SBK_QT_WINDOWFRAMESECTION_IDX                            = 409,
+    SBK_QT_COORDINATESYSTEM_IDX                              = 341,
+    SBK_QT_TOUCHPOINTSTATE_IDX                               = 404,
     SBK_QFLAGS_QT_TOUCHPOINTSTATE_IDX                        = 138,
-    SBK_QT_GESTURESTATE_IDX                                  = 354,
-    SBK_QT_GESTURETYPE_IDX                                   = 355,
-    SBK_QT_GESTUREFLAG_IDX                                   = 353,
+    SBK_QT_GESTURESTATE_IDX                                  = 357,
+    SBK_QT_GESTURETYPE_IDX                                   = 358,
+    SBK_QT_GESTUREFLAG_IDX                                   = 356,
     SBK_QFLAGS_QT_GESTUREFLAG_IDX                            = 124,
-    SBK_QT_NATIVEGESTURETYPE_IDX                             = 375,
-    SBK_QT_NAVIGATIONMODE_IDX                                = 376,
-    SBK_QT_CURSORMOVESTYLE_IDX                               = 417,
-    SBK_QT_TIMERTYPE_IDX                                     = 397,
-    SBK_QT_SCROLLPHASE_IDX                                   = 384,
-    SBK_QT_MOUSEEVENTSOURCE_IDX                              = 374,
-    SBK_QT_MOUSEEVENTFLAG_IDX                                = 373,
+    SBK_QT_NATIVEGESTURETYPE_IDX                             = 378,
+    SBK_QT_NAVIGATIONMODE_IDX                                = 379,
+    SBK_QT_CURSORMOVESTYLE_IDX                               = 420,
+    SBK_QT_TIMERTYPE_IDX                                     = 400,
+    SBK_QT_SCROLLPHASE_IDX                                   = 387,
+    SBK_QT_MOUSEEVENTSOURCE_IDX                              = 377,
+    SBK_QT_MOUSEEVENTFLAG_IDX                                = 376,
     SBK_QFLAGS_QT_MOUSEEVENTFLAG_IDX                         = 132,
-    SBK_QT_CHECKSUMTYPE_IDX                                  = 334,
-    SBK_QT_HIGHDPISCALEFACTORROUNDINGPOLICY_IDX              = 357,
-    SBK_QT_RETURNBYVALUECONSTANT_IDX                         = 381,
-    SBK_QtCoreQT_IDX                                         = 322,
-    SBK_QTCOREHELPER_QMUTEXLOCKER_IDX                        = 411,
+    SBK_QT_CHECKSUMTYPE_IDX                                  = 337,
+    SBK_QT_HIGHDPISCALEFACTORROUNDINGPOLICY_IDX              = 360,
+    SBK_QT_RETURNBYVALUECONSTANT_IDX                         = 384,
+    SBK_QtCoreQT_IDX                                         = 325,
+    SBK_QTCOREHELPER_QMUTEXLOCKER_IDX                        = 414,
     SBK_QCBORKNOWNTAGS_IDX                                   = 29,
     SBK_QCBORSIMPLETYPE_IDX                                  = 32,
-    SBK_QTMSGTYPE_IDX                                        = 412,
-    SBK_QtCore_IDX_COUNT                                     = 418
+    SBK_QTMSGTYPE_IDX                                        = 415,
+    SBK_QtCore_IDX_COUNT                                     = 421
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtCoreTypes;
@@ -887,6 +891,9 @@ template<> inline PyTypeObject *SbkType< ::QSettings::Status >() { return SbkPyS
 template<> inline PyTypeObject *SbkType< ::QSettings::Format >() { return SbkPySide6_QtCoreTypes[SBK_QSETTINGS_FORMAT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSettings::Scope >() { return SbkPySide6_QtCoreTypes[SBK_QSETTINGS_SCOPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSettings >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QSETTINGS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QSharedMemory::AccessMode >() { return SbkPySide6_QtCoreTypes[SBK_QSHAREDMEMORY_ACCESSMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSharedMemory::SharedMemoryError >() { return SbkPySide6_QtCoreTypes[SBK_QSHAREDMEMORY_SHAREDMEMORYERROR_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSharedMemory >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QSHAREDMEMORY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSignalBlocker >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QSIGNALBLOCKER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSignalMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QSIGNALMAPPER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSize >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtCoreTypes[SBK_QSIZE_IDX]); }
