@@ -51,18 +51,46 @@
 #include <pyside6_qtgui_python.h>
 
 // Bound library includes
+#include <QtOpenGL/qopenglfunctions_3_2_core.h>
+#include <QtOpenGL/qopenglfunctions_3_3_core.h>
+#include <QtOpenGL/qopenglfunctions_4_1_compatibility.h>
+#include <QtOpenGL/qopenglfunctions_4_4_core.h>
+#include <QtOpenGL/qopenglfunctions_4_5_core.h>
 #include <QtOpenGL/qopenglvertexarrayobject.h>
+#include <QtOpenGL/qopenglfunctions_4_1_core.h>
+#include <QtOpenGL/qopenglfunctions_1_5.h>
+#include <QtOpenGL/qopenglfunctions_4_5_compatibility.h>
+#include <QtOpenGL/qopengldebug.h>
+#include <QtOpenGL/qopenglfunctions_3_1.h>
+#include <QtOpenGL/qopenglfunctions_1_2.h>
+#include <QtOpenGL/qopenglfunctions_1_1.h>
+#include <QtOpenGL/qopenglfunctions_4_0_core.h>
+#include <QtOpenGL/qopenglfunctions_3_0.h>
+#include <QtOpenGL/qopenglfunctions_4_0_compatibility.h>
+#include <QtOpenGL/qopenglversionfunctions.h>
+#include <QtOpenGL/qopenglpaintdevice.h>
+#include <QtOpenGL/qopengltimerquery.h>
+#include <QtOpenGL/qopenglfunctions_1_4.h>
+#include <QtOpenGL/qopenglfunctions_4_4_compatibility.h>
+#include <QtOpenGL/qopenglfunctions_2_0.h>
 #include <QtOpenGL/qopengltextureblitter.h>
+#include <QtOpenGL/qopenglwindow.h>
+#include <QtOpenGL/qopenglfunctions_2_1.h>
+#include <QtOpenGL/qopenglshaderprogram.h>
+#include <QtOpenGL/qopenglframebufferobject.h>
+#include <QtOpenGL/qopenglfunctions_4_3_compatibility.h>
+#include <QtOpenGL/qopenglfunctions_4_2_core.h>
+#include <QtOpenGL/qopenglfunctions_1_0.h>
+#include <QtOpenGL/qopenglfunctions_1_3.h>
 #include <QtOpenGL/qopenglpixeltransferoptions.h>
 #include <QtOpenGL/qopenglversionprofile.h>
-#include <QtOpenGL/qopenglwindow.h>
+#include <QtOpenGL/qopenglfunctions_3_2_compatibility.h>
+#include <QtOpenGL/qopenglversionfunctionsfactory.h>
 #include <QtOpenGL/qopengltexture.h>
-#include <QtOpenGL/qopenglversionfunctions.h>
-#include <QtOpenGL/qopenglshaderprogram.h>
+#include <QtOpenGL/qopenglfunctions_4_2_compatibility.h>
 #include <QtOpenGL/qopenglbuffer.h>
-#include <QtOpenGL/qopengldebug.h>
-#include <QtOpenGL/qopenglframebufferobject.h>
-#include <QtOpenGL/qopengltimerquery.h>
+#include <QtOpenGL/qopenglfunctions_3_3_compatibility.h>
+#include <QtOpenGL/qopenglfunctions_4_3_core.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -102,41 +130,69 @@ enum : int {
     SBK_QOPENGLFRAMEBUFFEROBJECT_FRAMEBUFFERRESTOREPOLICY_IDX = 20,
     SBK_QOPENGLFRAMEBUFFEROBJECT_IDX                         = 18,
     SBK_QOPENGLFRAMEBUFFEROBJECTFORMAT_IDX                   = 21,
-    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 22,
-    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 24,
+    SBK_QOPENGLFUNCTIONS_1_0_IDX                             = 22,
+    SBK_QOPENGLFUNCTIONS_1_1_IDX                             = 23,
+    SBK_QOPENGLFUNCTIONS_1_2_IDX                             = 24,
+    SBK_QOPENGLFUNCTIONS_1_3_IDX                             = 25,
+    SBK_QOPENGLFUNCTIONS_1_4_IDX                             = 26,
+    SBK_QOPENGLFUNCTIONS_1_5_IDX                             = 27,
+    SBK_QOPENGLFUNCTIONS_2_0_IDX                             = 28,
+    SBK_QOPENGLFUNCTIONS_2_1_IDX                             = 29,
+    SBK_QOPENGLFUNCTIONS_3_0_IDX                             = 30,
+    SBK_QOPENGLFUNCTIONS_3_1_IDX                             = 31,
+    SBK_QOPENGLFUNCTIONS_3_2_COMPATIBILITY_IDX               = 32,
+    SBK_QOPENGLFUNCTIONS_3_2_CORE_IDX                        = 33,
+    SBK_QOPENGLFUNCTIONS_3_3_COMPATIBILITY_IDX               = 34,
+    SBK_QOPENGLFUNCTIONS_3_3_CORE_IDX                        = 35,
+    SBK_QOPENGLFUNCTIONS_4_0_COMPATIBILITY_IDX               = 36,
+    SBK_QOPENGLFUNCTIONS_4_0_CORE_IDX                        = 37,
+    SBK_QOPENGLFUNCTIONS_4_1_COMPATIBILITY_IDX               = 38,
+    SBK_QOPENGLFUNCTIONS_4_1_CORE_IDX                        = 39,
+    SBK_QOPENGLFUNCTIONS_4_2_COMPATIBILITY_IDX               = 40,
+    SBK_QOPENGLFUNCTIONS_4_2_CORE_IDX                        = 41,
+    SBK_QOPENGLFUNCTIONS_4_3_COMPATIBILITY_IDX               = 42,
+    SBK_QOPENGLFUNCTIONS_4_3_CORE_IDX                        = 43,
+    SBK_QOPENGLFUNCTIONS_4_4_COMPATIBILITY_IDX               = 44,
+    SBK_QOPENGLFUNCTIONS_4_4_CORE_IDX                        = 45,
+    SBK_QOPENGLFUNCTIONS_4_5_COMPATIBILITY_IDX               = 46,
+    SBK_QOPENGLFUNCTIONS_4_5_CORE_IDX                        = 47,
+    SBK_QOPENGLPAINTDEVICE_IDX                               = 49,
+    SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX                      = 50,
+    SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX                      = 52,
     SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX               = 5,
-    SBK_QOPENGLSHADER_IDX                                    = 23,
-    SBK_QOPENGLSHADERPROGRAM_IDX                             = 25,
-    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 40,
-    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 27,
-    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 35,
-    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 43,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 41,
-    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 42,
-    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 31,
-    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 36,
-    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 37,
-    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 38,
-    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 39,
-    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 44,
-    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 30,
-    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 33,
+    SBK_QOPENGLSHADER_IDX                                    = 51,
+    SBK_QOPENGLSHADERPROGRAM_IDX                             = 53,
+    SBK_QOPENGLTEXTURE_TARGET_IDX                            = 68,
+    SBK_QOPENGLTEXTURE_BINDINGTARGET_IDX                     = 55,
+    SBK_QOPENGLTEXTURE_MIPMAPGENERATION_IDX                  = 63,
+    SBK_QOPENGLTEXTURE_TEXTUREUNITRESET_IDX                  = 71,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMAT_IDX                     = 69,
+    SBK_QOPENGLTEXTURE_TEXTUREFORMATCLASS_IDX                = 70,
+    SBK_QOPENGLTEXTURE_CUBEMAPFACE_IDX                       = 59,
+    SBK_QOPENGLTEXTURE_PIXELFORMAT_IDX                       = 64,
+    SBK_QOPENGLTEXTURE_PIXELTYPE_IDX                         = 65,
+    SBK_QOPENGLTEXTURE_SWIZZLECOMPONENT_IDX                  = 66,
+    SBK_QOPENGLTEXTURE_SWIZZLEVALUE_IDX                      = 67,
+    SBK_QOPENGLTEXTURE_WRAPMODE_IDX                          = 72,
+    SBK_QOPENGLTEXTURE_COORDINATEDIRECTION_IDX               = 58,
+    SBK_QOPENGLTEXTURE_FEATURE_IDX                           = 61,
     SBK_QFLAGS_QOPENGLTEXTURE_FEATURE_IDX                    = 6,
-    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 32,
-    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 28,
-    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 29,
-    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 34,
-    SBK_QOPENGLTEXTURE_IDX                                   = 26,
-    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 46,
-    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 45,
-    SBK_QOPENGLTIMEMONITOR_IDX                               = 47,
-    SBK_QOPENGLTIMERQUERY_IDX                                = 48,
-    SBK_QOPENGLVERSIONPROFILE_IDX                            = 49,
-    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 50,
-    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 51,
-    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 53,
-    SBK_QOPENGLWINDOW_IDX                                    = 52,
-    SBK_QtOpenGL_IDX_COUNT                                   = 54
+    SBK_QOPENGLTEXTURE_DEPTHSTENCILMODE_IDX                  = 60,
+    SBK_QOPENGLTEXTURE_COMPARISONFUNCTION_IDX                = 56,
+    SBK_QOPENGLTEXTURE_COMPARISONMODE_IDX                    = 57,
+    SBK_QOPENGLTEXTURE_FILTER_IDX                            = 62,
+    SBK_QOPENGLTEXTURE_IDX                                   = 54,
+    SBK_QOPENGLTEXTUREBLITTER_ORIGIN_IDX                     = 74,
+    SBK_QOPENGLTEXTUREBLITTER_IDX                            = 73,
+    SBK_QOPENGLTIMEMONITOR_IDX                               = 75,
+    SBK_QOPENGLTIMERQUERY_IDX                                = 76,
+    SBK_QOPENGLVERSIONFUNCTIONSFACTORY_IDX                   = 77,
+    SBK_QOPENGLVERSIONPROFILE_IDX                            = 78,
+    SBK_QOPENGLVERTEXARRAYOBJECT_IDX                         = 79,
+    SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX                  = 80,
+    SBK_QOPENGLWINDOW_UPDATEBEHAVIOR_IDX                     = 82,
+    SBK_QOPENGLWINDOW_IDX                                    = 81,
+    SBK_QtOpenGL_IDX_COUNT                                   = 83
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtOpenGLTypes;
@@ -154,15 +210,16 @@ enum : int {
     SBK_QTOPENGL_QPAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 2, // QPair<QOpenGLTexture::Filter,QOpenGLTexture::Filter >
     SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 3, // QList<QSize >
     SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 4, // QList<unsigned int >
-    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 5, // const QList<QObject* > &
+    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 5, // QList<QObject* >
     SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 6, // QList<QByteArray >
-    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 7, // QList<float >
-    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 8, // QList<QOpenGLShader* >
-    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 9, // QList<QOpenGLDebugMessage >
-    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 10, // QList<QVariant >
-    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 11, // QList<QString >
-    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 12, // QMap<QString,QVariant >
-    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 13
+    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 7, // QList<uint64_t >
+    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 8, // QList<float >
+    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 9, // QList<QOpenGLShader* >
+    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 10, // QList<QOpenGLDebugMessage >
+    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 11, // QList<QVariant >
+    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 12, // QList<QString >
+    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 13, // QMap<QString,QVariant >
+    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 14
 };
 // Macros for type check
 
@@ -192,6 +249,33 @@ template<> inline PyTypeObject *SbkType< ::QOpenGLFramebufferObject::Attachment
 template<> inline PyTypeObject *SbkType< ::QOpenGLFramebufferObject::FramebufferRestorePolicy >() { return SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFRAMEBUFFEROBJECT_FRAMEBUFFERRESTOREPOLICY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QOpenGLFramebufferObject >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFRAMEBUFFEROBJECT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLFramebufferObjectFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFRAMEBUFFEROBJECTFORMAT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_1_0 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_1_0_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_1_1 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_1_1_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_1_2 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_1_2_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_1_3 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_1_3_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_1_4 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_1_4_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_1_5 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_1_5_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_2_0 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_2_0_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_2_1 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_2_1_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_3_0 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_3_0_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_3_1 >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_3_1_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_3_2_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_3_2_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_3_2_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_3_2_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_3_3_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_3_3_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_3_3_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_3_3_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_0_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_0_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_0_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_0_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_1_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_1_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_1_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_1_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_2_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_2_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_2_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_2_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_3_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_3_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_3_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_3_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_4_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_4_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_4_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_4_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_5_Compatibility >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_5_COMPATIBILITY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLFunctions_4_5_Core >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLFUNCTIONS_4_5_CORE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLPaintDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLPAINTDEVICE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLPixelTransferOptions >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLPIXELTRANSFEROPTIONS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLShader::ShaderTypeBit >() { return SbkPySide6_QtOpenGLTypes[SBK_QOPENGLSHADER_SHADERTYPEBIT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QOpenGLShader::ShaderTypeBit> >() { return SbkPySide6_QtOpenGLTypes[SBK_QFLAGS_QOPENGLSHADER_SHADERTYPEBIT_IDX]; }
@@ -221,6 +305,7 @@ template<> inline PyTypeObject *SbkType< ::QOpenGLTextureBlitter::Origin >() { r
 template<> inline PyTypeObject *SbkType< ::QOpenGLTextureBlitter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLTEXTUREBLITTER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLTimeMonitor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLTIMEMONITOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLTimerQuery >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLTIMERQUERY_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QOpenGLVersionFunctionsFactory >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLVERSIONFUNCTIONSFACTORY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLVersionProfile >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLVERSIONPROFILE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLVertexArrayObject >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLVERTEXARRAYOBJECT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QOpenGLVertexArrayObject::Binder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtOpenGLTypes[SBK_QOPENGLVERTEXARRAYOBJECT_BINDER_IDX]); }
